from accerciser.plugin import Plugin
import gtk
import pyatspi

# We will derive a new class from the Plugin base class,
# and assign some mandatory class attributes:
class FocusSelect(Plugin):
  plugin_name = 'Focus Select'
  plugin_description = 'Allows selecting last focused accessible.'
  # Override the init method.
  def init(self):
    # Register an event listener for the "focus" event
    pyatspi.Registry.registerEventListener(self.accEventFocusChanged, 
                                           'focus')

    # The global_hotkeys instance variable is a list of tuples, 
    # each tuple is one global hotkey action, and it is a list of 
    # an action description, desired method to call, key symbol of 
    # keypress, and a key modifier mask.
    self.global_hotkeys = [('Inspect last focused accessible',
                            self.inspectLastFocused, 
                            gtk.keysyms.e,
                            gtk.gdk.CONTROL_MASK | gtk.gdk.MOD1_MASK)]    

    # Initialize as None.
    self.last_focused = None

  # In this callback we assign the last_focused instance variable 
  # with the accessible that just just emitted the "focus" event.
  def accEventFocusChanged(self, event):
    if not self.isMyApp(event.source):
      self.last_focused = event.source      

  # In the hotkey action callback we update the application
  # wide node with the last focused accessible, if we have recorded it.
  def inspectLastFocused(self):
    if self.last_focused:
      self.node.update(self.last_focused)

  
